==> claromentis-framework-9.6.6-26891208.zip: web/intranet/documents/classes/workflow/WFTransitionFactory.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] ?: array()) + array("_08aa8c9631295656e6b3f" . "403b6dcceb3" => base64_decode("d2ZfaWQ9aW5" . "0OndmX2lk"), "i" . "d" => base64_decode("aWQ" . "="), "_b963770c44230eb" . "e4fec8fa56a7164c" . "7" => base64_decode("ZnJvbV9zdGF0dXMgPSBpbnQ6c3RhdGVf" . "aWQ="), "_7d31eb6" . "1ac33303" . "230c2310" . "2fdfd52c" . "3" => base64_decode("Tm9uZQ" . "=="));




class WFTransitionFactory
{
    
    
    
    
    
    
    
    public static function CreateInstance($_7225eff8b08a45e56a04943da5f8ef2b)
    {
        $_6d531f6dc9e331a0e9b18556f51742ea = null;
        switch ($_7225eff8b08a45e56a04943da5f8ef2b) {
            case WF_TRANSITION_NONE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionNone();
                break;
            case WF_TRANSITION_TIME_ELAPSE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionPeriod();
                break;
            case WF_TRANSITION_DATETIME:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionDatetime();
                break;
            case WF_TRANSITION_PERIOD:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionPeriod();
                break;
            case WF_TRANSITION_ALL_APPROVE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionAllApprove();
                break;
            case WF_TRANSITION_ONE_APPROVE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionOneApprove();
                break;
            default:
                return null;
                
                
        }
        $_6d531f6dc9e331a0e9b18556f51742ea->SetType($_7225eff8b08a45e56a04943da5f8ef2b);
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    public static function LoadInstance($id)
    {
        $_c4c0f15c5891a8ac349f1b56352500b5 = new WFTransition();
        if (!$_c4c0f15c5891a8ac349f1b56352500b5->Load($id)) {
            return false;
        }
        $_6d531f6dc9e331a0e9b18556f51742ea = WFTransitionFactory::CreateInstance($_c4c0f15c5891a8ac349f1b56352500b5->GetType());
        if (!$_6d531f6dc9e331a0e9b18556f51742ea) {
            return false;
        }
        if (!$_6d531f6dc9e331a0e9b18556f51742ea->Load($id)) {
            return false;
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    public static function GetAllInstancesByState($_226b051490848e9e1835697931696225)
    {
        global $db;
        if ($_226b051490848e9e1835697931696225 <= 0) {
            return array();
        }
        $_c4c0f15c5891a8ac349f1b56352500b5 = new WFTransition();
        $_714e1da7f6235557a4490c30b448e1ad = $_c4c0f15c5891a8ac349f1b56352500b5->GenerateSelect();
        $_714e1da7f6235557a4490c30b448e1ad->AddWhereAndClause($GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_b963770c44230ebe4fec8fa56a7" . "164c7"], $_226b051490848e9e1835697931696225);
        $_7f5aa4e96d4b415a86ed72ebff677cbe = $_714e1da7f6235557a4490c30b448e1ad->GetQuery();
        $_1f24efd4735b7a11b391147435e7d35d = $db->query($_7f5aa4e96d4b415a86ed72ebff677cbe);
        $_6d531f6dc9e331a0e9b18556f51742ea = array();
        while (($_b8cfc2e06d9d1fec1893ea4a054002bf = $_1f24efd4735b7a11b391147435e7d35d->fetchArray()) != null) {
            $_07e41711580f2279161feffa9f744876 = WFTransitionFactory::LoadInstance($_b8cfc2e06d9d1fec1893ea4a054002bf[$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["i" . "d"]]);
            if ($_07e41711580f2279161feffa9f744876) {
                $_6d531f6dc9e331a0e9b18556f51742ea[] = $_07e41711580f2279161feffa9f744876;
            }
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    public static function GetAllInstancesByWF($_eb57e3a45673c8e851b42c4eee3742ea)
    {
        global $db;
        if ($_eb57e3a45673c8e851b42c4eee3742ea <= 0) {
            return array();
        }
        $_c4c0f15c5891a8ac349f1b56352500b5 = new WFTransition();
        $_714e1da7f6235557a4490c30b448e1ad = $_c4c0f15c5891a8ac349f1b56352500b5->GenerateSelect();
        $_714e1da7f6235557a4490c30b448e1ad->AddWhereAndClause($GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_08aa8c9631295656e6b3f403b6d" . "cceb3"], $_eb57e3a45673c8e851b42c4eee3742ea);
        $_7f5aa4e96d4b415a86ed72ebff677cbe = $_714e1da7f6235557a4490c30b448e1ad->GetQuery();
        $_1f24efd4735b7a11b391147435e7d35d = $db->query($_7f5aa4e96d4b415a86ed72ebff677cbe);
        $_6d531f6dc9e331a0e9b18556f51742ea = array();
        while (($_b8cfc2e06d9d1fec1893ea4a054002bf = $_1f24efd4735b7a11b391147435e7d35d->fetchArray()) != null) {
            $_07e41711580f2279161feffa9f744876 = WFTransitionFactory::LoadInstance($_b8cfc2e06d9d1fec1893ea4a054002bf[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["i" . "d"]]);
            if ($_07e41711580f2279161feffa9f744876) {
                $_6d531f6dc9e331a0e9b18556f51742ea[] = $_07e41711580f2279161feffa9f744876;
            }
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    public static function GetAllTitles()
    {
        $_6d531f6dc9e331a0e9b18556f51742ea = array();
        $_6d531f6dc9e331a0e9b18556f51742ea[WF_TRANSITION_NONE] = $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_7d31eb61ac33303230c23" . "102fdfd52c3"];
        
        
        
        
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/documents/classes/workflow/WFTransitionFactory.php <==
<?php
$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] ?: array()) + array("_08aa8c9631295656e6b3f403b6" . "dcceb3" => base64_decode("d2ZfaWQ9aW50On" . "dmX2lk"), "i" . "d" => base64_decode("a" . "W" . "Q" . "="), "_7d31eb61ac33303230c" . "23102fdfd52c3" => base64_decode("Tm9" . "uZQ" . "=="), "_b963770c4" . "4230ebe4fe" . "c8fa56a716" . "4c7" => base64_decode("ZnJvbV9zdGF0dXMgPSBpbnQ6c" . "3RhdGVfaWQ="));




class WFTransitionFactory
{
    
    
    
    
    
    
    
    public static function CreateInstance($_7225eff8b08a45e56a04943da5f8ef2b)
    {
        $_6d531f6dc9e331a0e9b18556f51742ea = null;
        switch ($_7225eff8b08a45e56a04943da5f8ef2b) {
            case WF_TRANSITION_NONE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionNone();
                break;
            case WF_TRANSITION_TIME_ELAPSE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionPeriod();
                break;
            case WF_TRANSITION_DATETIME:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionDatetime();
                break;
            case WF_TRANSITION_PERIOD:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionPeriod();
                break;
            case WF_TRANSITION_ALL_APPROVE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionAllApprove();
                break;
            case WF_TRANSITION_ONE_APPROVE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionOneApprove();
                break;
            default:
                return null;
                
                
        }
        $_6d531f6dc9e331a0e9b18556f51742ea->SetType($_7225eff8b08a45e56a04943da5f8ef2b);
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    public static function LoadInstance($id)
    {
        $_c4c0f15c5891a8ac349f1b56352500b5 = new WFTransition();
        if (!$_c4c0f15c5891a8ac349f1b56352500b5->Load($id)) {
            return false;
        }
        $_6d531f6dc9e331a0e9b18556f51742ea = WFTransitionFactory::CreateInstance($_c4c0f15c5891a8ac349f1b56352500b5->GetType());
        if (!$_6d531f6dc9e331a0e9b18556f51742ea) {
            return false;
        }
        if (!$_6d531f6dc9e331a0e9b18556f51742ea->Load($id)) {
            return false;
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    public static function GetAllInstancesByState($_226b051490848e9e1835697931696225)
    {
        global $db;
        if ($_226b051490848e9e1835697931696225 <= 0) {
            return array();
        }
        $_c4c0f15c5891a8ac349f1b56352500b5 = new WFTransition();
        $_714e1da7f6235557a4490c30b448e1ad = $_c4c0f15c5891a8ac349f1b56352500b5->GenerateSelect();
        $_714e1da7f6235557a4490c30b448e1ad->AddWhereAndClause($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_b963770c442" . "30ebe4fec8fa" . "56a7164c7"], $_226b051490848e9e1835697931696225);
        $_7f5aa4e96d4b415a86ed72ebff677cbe = $_714e1da7f6235557a4490c30b448e1ad->GetQuery();
        $_1f24efd4735b7a11b391147435e7d35d = $db->query($_7f5aa4e96d4b415a86ed72ebff677cbe);
        $_6d531f6dc9e331a0e9b18556f51742ea = array();
        while (($_b8cfc2e06d9d1fec1893ea4a054002bf = $_1f24efd4735b7a11b391147435e7d35d->fetchArray()) != null) {
            $_07e41711580f2279161feffa9f744876 = WFTransitionFactory::LoadInstance($_b8cfc2e06d9d1fec1893ea4a054002bf[$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["i" . "d"]]);
            if ($_07e41711580f2279161feffa9f744876) {
                $_6d531f6dc9e331a0e9b18556f51742ea[] = $_07e41711580f2279161feffa9f744876;
            }
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    public static function GetAllInstancesByWF($_eb57e3a45673c8e851b42c4eee3742ea)
    {
        global $db;
        if ($_eb57e3a45673c8e851b42c4eee3742ea <= 0) {
            return array();
        }
        $_c4c0f15c5891a8ac349f1b56352500b5 = new WFTransition();
        $_714e1da7f6235557a4490c30b448e1ad = $_c4c0f15c5891a8ac349f1b56352500b5->GenerateSelect();
        $_714e1da7f6235557a4490c30b448e1ad->AddWhereAndClause($GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_08aa8c9631295656e6b3f403b6d" . "cceb3"], $_eb57e3a45673c8e851b42c4eee3742ea);
        $_7f5aa4e96d4b415a86ed72ebff677cbe = $_714e1da7f6235557a4490c30b448e1ad->GetQuery();
        $_1f24efd4735b7a11b391147435e7d35d = $db->query($_7f5aa4e96d4b415a86ed72ebff677cbe);
        $_6d531f6dc9e331a0e9b18556f51742ea = array();
        while (($_b8cfc2e06d9d1fec1893ea4a054002bf = $_1f24efd4735b7a11b391147435e7d35d->fetchArray()) != null) {
            $_07e41711580f2279161feffa9f744876 = WFTransitionFactory::LoadInstance($_b8cfc2e06d9d1fec1893ea4a054002bf[$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["i" . "d"]]);
            if ($_07e41711580f2279161feffa9f744876) {
                $_6d531f6dc9e331a0e9b18556f51742ea[] = $_07e41711580f2279161feffa9f744876;
            }
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    public static function GetAllTitles()
    {
        $_6d531f6dc9e331a0e9b18556f51742ea = array();
        $_6d531f6dc9e331a0e9b18556f51742ea[WF_TRANSITION_NONE] = $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_7d31eb61ac333" . "03230c23102fdf" . "d52c3"];
        
        
        
        
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
}
